@@ -182,14 +182,14 @@ class VizCommand(BuildGraphCommand):
                 task.path,
                 penwidth="3" if task.default else "1",
                 fillcolor=(
-                    "darkgoldenrod1"
-                    if task in executed_tasks
-                    else "dodgerblue"
+                    "dodgerblue"
                     if isinstance(task, GroupTask)
+                    else "darkgoldenrod1"
+                    if task in executed_tasks
                     else "beige"
                 ),
             )
-            for predecessor in graph.get_predecessors(task):
+            for predecessor in graph.get_predecessors(task, ignore_groups=False):
                 writer.edge(predecessor.path, task.path)
 
         writer.end()
