@@ -5,15 +5,16 @@ from termcolor import colored
 COLORS_BY_STATUS = {
     TaskStatusType.PENDING: "magenta",
     TaskStatusType.FAILED: "red",
+    TaskStatusType.INTERRUPTED: "red",
     TaskStatusType.SKIPPED: "yellow",
     TaskStatusType.SUCCEEDED: "green",
-    TaskStatusType.STARTED: "green",
+    TaskStatusType.STARTED: "magenta",
     TaskStatusType.UP_TO_DATE: "green",
 }
 
 
 def status_to_text(status: TaskStatus) -> str:
-    message = colored(status.type.name, COLORS_BY_STATUS[status.type])
+    message = colored(status.type.name, COLORS_BY_STATUS.get(status.type))
     if status.message:
         message += f" ({status.message})"
     return message
